@@ -43,6 +43,18 @@ class S3File(object):
                 return True
         return False
 
+    def get_obj_content(self, key, bucket_name):
+        """
+        获取s3中文件内容
+        :param key: 文件key
+        :param bucket_name: 桶名
+        :return: 无该对象返回None，否则返回文件中字符串内容
+        """
+        if not self.file_exists(key, bucket_name):
+            return None
+        content_object = self.server.Object(bucket_name, key)
+        return content_object.get()['Body'].read().decode('utf-8')
+
     def download(self, file_name, aim_path, bucket_name):
         """
         下载文件接口
@@ -154,6 +166,10 @@ if __name__ == '__main__':
     print('start')
     start = time.time()
     s3_file = S3File('aws')
+    conetnt = s3_file.get_obj_content('news/news_post/2020/07/04/22ArPS7wn6Xd2PvoRSRiHN/20200416.txt', 'sdai-alg')
+    print(conetnt)
+    import pdb
+    pdb.set_trace()
     end = time.time()
     _path = '/Users/liuguangbin/Documents/sd_lk_backend.tar'
     res = s3_file.upload_content('news/test.txt', json.dumps({'a': 123, 'sdf': '胜多负少的阀'}), 'sdai-alg')
